@@ -1,9 +1,9 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # SoundConverter - GNOME application for converting between audio formats.
 # Copyright 2004 Lars Wirzenius
-# Copyright 2005-2020 Gautier Portet
+# Copyright 2005-2025 Gautier Portet
+# Copyright 2020-2025 Sezanzeb
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,23 +19,25 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 # USA
 
+import threading
 import time
 import unittest
-import threading
 from unittest.mock import Mock
-from gi.repository import GLib, Gst
 
-from soundconverter.util.taskqueue import TaskQueue, Timer
-from soundconverter.util.task import Task
-from soundconverter.util.settings import get_gio_settings
+from gi.repository import GLib, Gst
 from util import reset_settings
 
+from soundconverter.util.settings import get_gio_settings
+from soundconverter.util.task import Task
+from soundconverter.util.taskqueue import TaskQueue, Timer
+
 
 class SyncSleepTask(Task):
     """Task that does nothing.
 
     Multiple of those tasks can't run in parallel.
     """
+
     def __init__(self):
         super().__init__()
 
@@ -50,7 +52,7 @@ class SyncSleepTask(Task):
 
     def run(self):
         time.sleep(0.1)
-        self.emit('done')
+        self.emit("done")
 
     def pause(self):
         # cannot be paused
@@ -65,6 +67,7 @@ class AsyncSleepTask(Task):
 
     Can run in parallel. This is just an example on how a Task might work.
     """
+
     def __init__(self):
         self.progress = 0
         self.paused = False
@@ -121,7 +124,7 @@ class AsyncSleepTask(Task):
     def run(self):
         self.cancelled = False
         bus = Gst.Bus()
-        bus.connect('message', self.done)
+        bus.connect("message", self.done)
         bus.add_signal_watch()
         thread = threading.Thread(target=self.async_stuff, args=(bus,))
         thread.start()
@@ -138,13 +141,14 @@ class SyncSleepTaskTest(unittest.TestCase):
         """Checks if basic Task class functions are working properly."""
         task = SyncSleepTask()
         done = Mock()
-        task.connect('done', done)
+        task.connect("done", done)
         task.run()
         done.assert_called_with(task)
 
 
 class AsyncSleepTaskTest(unittest.TestCase):
     """Checks if async Task class functions are working properly."""
+
     def test_pause_resume(self):
         loop = GLib.MainLoop()
         context = loop.get_context()
@@ -152,7 +156,7 @@ class AsyncSleepTaskTest(unittest.TestCase):
         task = AsyncSleepTask()
         self.assertEqual(task.get_progress()[0], 0)
         done = Mock()
-        task.connect('done', done)
+        task.connect("done", done)
 
         task.run()
         time.sleep(0.15)
@@ -180,7 +184,7 @@ class AsyncSleepTaskTest(unittest.TestCase):
 
         task = AsyncSleepTask()
         done = Mock()
-        task.connect('done', done)
+        task.connect("done", done)
 
         task.run()
         time.sleep(0.15)
@@ -208,8 +212,9 @@ class AsyncSleepTaskTest(unittest.TestCase):
 
 class AsyncMulticoreTaskQueueTest(unittest.TestCase):
     """Example closest to the real world, should be tested well."""
+
     def setUp(self):
-        get_gio_settings().set_boolean('limit-jobs', True)
+        get_gio_settings().set_boolean("limit-jobs", True)
         self.num_tasks = 5
         q = TaskQueue()
         for i in range(self.num_tasks):
@@ -225,7 +230,7 @@ class AsyncMulticoreTaskQueueTest(unittest.TestCase):
 
     def test_queue_multiple_async(self):
         self.num_jobs = 2
-        get_gio_settings().set_int('number-of-jobs', self.num_jobs)
+        get_gio_settings().set_int("number-of-jobs", self.num_jobs)
 
         self.q.run()
         self.assertEqual(len(self.q.done), 0)
@@ -250,7 +255,7 @@ class AsyncMulticoreTaskQueueTest(unittest.TestCase):
 
     def test_pause_resume(self):
         self.num_jobs = 5
-        get_gio_settings().set_int('number-of-jobs', self.num_jobs)
+        get_gio_settings().set_int("number-of-jobs", self.num_jobs)
 
         self.assertEqual(self.q.get_progress()[0], 0)
         self.assertEqual(self.q.pending.qsize(), self.num_tasks)
@@ -331,7 +336,7 @@ class AsyncMulticoreTaskQueueTest(unittest.TestCase):
     def test_cancel_run(self):
         # all tasks are running at once
         self.num_jobs = 5
-        get_gio_settings().set_int('number-of-jobs', self.num_jobs)
+        get_gio_settings().set_int("number-of-jobs", self.num_jobs)
 
         loop = GLib.MainLoop()
         context = loop.get_context()
@@ -405,8 +410,8 @@ class TaskQueueTest(unittest.TestCase):
 
     def test_queue_single(self):
         """A TaskQueue only consisting of synchronous tasks."""
-        get_gio_settings().set_boolean('limit-jobs', True)
-        get_gio_settings().set_int('number-of-jobs', 1)
+        get_gio_settings().set_boolean("limit-jobs", True)
+        get_gio_settings().set_int("number-of-jobs", 1)
         q = TaskQueue()
 
         q.add(SyncSleepTask())
@@ -422,8 +427,8 @@ class TaskQueueTest(unittest.TestCase):
         self.assertEqual(len(q.running), 0)
 
     def test_queue_single_async(self):
-        get_gio_settings().set_boolean('limit-jobs', True)
-        get_gio_settings().set_int('number-of-jobs', 1)
+        get_gio_settings().set_boolean("limit-jobs", True)
+        get_gio_settings().set_int("number-of-jobs", 1)
         q = TaskQueue()
 
         q.add(AsyncSleepTask())
